{% import "partials/language.html" as lang with context %}

<!-- Footer -->
<footer class="md-footer">

  <!-- Link to previous and/or next page -->
  {% if page.previous_page or page.next_page %}
    <nav
      class="md-footer__inner md-grid"
      aria-label="{{ lang.t('footer.title') }}"
    >

      <!-- Link to previous page -->
      {% if page.previous_page %}
        {% set direction = lang.t("footer.previous") %}
        <a
          href="{{ page.previous_page.url | url }}"
          class="md-footer__link md-footer__link--prev"
          aria-label="{{ direction }}: {{ page.previous_page.title | e }}"
          rel="prev"
        >
          <div class="md-footer__button md-icon">
            {% include ".icons/material/arrow-left.svg" %}
          </div>
          <div class="md-footer__title">
            <div class="md-ellipsis">
              <span class="md-footer__direction">
                {{ direction }}
              </span>
              {{ page.previous_page.title }}
            </div>
          </div>
        </a>
      {% endif %}

      <!-- Link to next page -->
      {% if page.next_page %}
        {% set direction = lang.t("footer.next") %}
        <a
          href="{{ page.next_page.url | url }}"
          class="md-footer__link md-footer__link--next"
          aria-label="{{ direction }}: {{ page.next_page.title | e }}"
          rel="next"
        >
          <div class="md-footer__title">
            <div class="md-ellipsis">
              <span class="md-footer__direction">
                {{ direction }}
              </span>
              {{ page.next_page.title }}
            </div>
          </div>
          <div class="md-footer__button md-icon">
            {% include ".icons/material/arrow-right.svg" %}
          </div>
        </a>
      {% endif %}
    </nav>
  {% endif %}

  <!-- Further information -->
  <div class="md-footer-meta md-typeset">
    <div class="md-footer-meta__inner md-grid">

      <!-- Copyright and theme information -->
      <div class="md-footer-copyright">
        {% if config.copyright %}
          <div class="md-footer-copyright__highlight">
            {{ config.copyright }}
          </div>
        {% endif %}
       <!-- {% if not config.extra.generator == false %}
          Made with
          <a
            href="https://squidfunk.github.io/mkdocs-material/"
            target="_blank" rel="noopener"
          >
            Material for MkDocs
          </a>
        {% endif %}-->
        {{ extracopyright }}
      </div>

      <!-- Social links -->
      {% include "partials/social.html" %}
    </div>
  </div>
</footer>