{% extends "base.html" %}

{% block libs %}
  <script
    src="https://code.jquery.com/jquery-3.6.0.min.js"
    integrity="sha256-/xUj+3OJU5yExlq6GSYGSHk7tPXikynS7ogEvDej/m4="
    crossorigin="anonymous"></script>
{% endblock %}

<!--
{% block hero %}
  {% if page and page.meta and page.meta.hero %}
    Test hero
  {% endif %}
{% endblock %}
-->

<!-- Content -->
{% block content %}

<!-- Last update of source file -->
{% if page and page.meta %}
  {% if page.meta.git_revision_date_localized or
  page.meta.revision_date
  %}
    {% include "partials/source-file.html" %}
  {% endif %}
{% endif %}

<!--
  Hack: check whether the content contains a h1 headline. If it
  doesn't, the page title (or respectively site name) is used
  as the main headline.
-->
{% if not "\x3ch1" in page.content %}
<h1>{{ page.title | d(config.site_name, true)}}</h1>
{% endif %}


<!-- Markdown content -->
{{ page.content }}

{% endblock %}

{% block scripts %}
  {{ super() }}
  {% if config.extra.debug %}
    {% include "partials/debug.html" %}
  {% endif %}
{% endblock %}

<!--
{% block announce %}
  {% if config.extra.announce %}
    {{ config.extra.announce }}
  {% else %}
    
    <style>
      div[data-md-component="announce"] {
        display: none;
      }
    </style>
  {% endif %}
{% endblock %}-->
