{% extends "main.html" %}
{% block tabs %}
{{ super() }}
<link rel="stylesheet" href="{{ 'assets/stylesheets/home.css' | url }}">
<section class="mdx-container">
  <div class="md-grid md-typeset">
    <div class="mdx-hero">
      <div class="mdx-hero__image">
        <img src="{{ 'assets/images/illustration.png' | url }}" alt="" draggable="false">
      </div>
      <div class="mdx-hero__content">
        <h1>{{ page.meta.title }}</h1>
        <p>{{ page.meta.description }}</p>
        {% for link in page.meta.links %}
        <a href="{{ link.link | url }}" title="{{ link.title | e }}"
           class="md-button{% if loop.index <= 1 %} md-button--primary{% endif %}">
          {{ link.title | e }}
        </a>
        {% endfor %}
      </div>
    </div>
  </div>
</section>
{% endblock %}

{% block content %}{% endblock %}
