MOCK_CACTUS_TRANSACTION_DETAIL_1 = {
    "transactionStatus": "completed",
    "transactionHash": "0xc062e8e89fa6447b59fc981fa6be352d012bd8bf92bb6833626bcb34c89ce455",
    "custodian_transactionId": "VHV3LIBLVND888888000431",
    "gasPrice": "1000000008",
    "maxFeePerGas": "3500000012",
    "maxPriorityFeePerGas": "1000000000",
    "gasLimit": "1500000",
    "nonce": "4",
    "from": "0xA7f5D02E141c5DF8A987833E01E4f0922A91cF29",
    "signature": None,
}
