MOCK_MMICONFIG_DEV = {
    "portfolio": None,
    "custodians": [
        {
            "refreshTokenUrl": "https://hi.ho",
            "name": "saturn",
            "apiBaseUrl": "https://test.net",
        },
    ]
}
