.md-header {
  position: initial
}

.md-main__inner {
  margin: 0
}

.md-content {
  display: none
}

.md-footer {
  margin-top: 0 !important;
}

@media screen and (min-width: 60em) {
  .md-sidebar--secondary {
    display: none
  }
}

@media screen and (min-width: 76.25em) {
  .md-sidebar--primary {
    display: none
  }
}

.mdx-container {
  padding-top: 2rem;
  background: var(--md-wave-background);
}

.mdx-hero {
  margin: 0 0.8rem;
  color: var(--mdx-hero-color);
}

.mdx-hero h1 {
  margin-bottom: 1rem;
  color: currentColor;
  font-weight: 700;
}

@media screen and (max-width: 29.9375em) {
  .mdx-hero h1 {
    font-size: 1.4rem;
  }
}
.mdx-hero__content {
  padding-bottom: 6rem;
}
@media screen and (min-width: 60em) {
  .mdx-hero {
    display: flex;
    align-items: stretch;
  }
  .mdx-hero__content {
    max-width: 24rem;
    margin-top: 3.5rem;
    padding-bottom: 14vw;
  }
  .mdx-hero__image {
    order: 1;
    width: 38rem;
    transform: translateX(4rem);
  }
}
/*@media screen and (min-width: 76.25em) {*/
/*  .mdx-hero__image {*/
/*    transform: translateX(8rem);*/
/*  }*/
/*}*/
.mdx-hero .md-button {
  margin-top: 0.5rem;
  margin-right: 0.5rem;
  color: var(--md-primary-bg-color);
}
.mdx-hero .md-button:focus, .mdx-hero .md-button:hover {
  color: var(--md-accent-bg-color);
  background-color: var(--md-accent-fg-color);
  border-color: var(--md-accent-fg-color);
}
.mdx-hero .md-button--primary {
  color: #894da8;
  background-color: var(--md-primary-bg-color);
  border-color: var(--md-primary-bg-color);
}

[data-md-color-scheme="consensys"] {
  /*--md-footer-bg-color: rgba(0,0,0,0.87);*/
  --md-footer-bg-color: rgb(33 63 164);
  --md-default-bg-color: var(--md-footer-bg-color);
  --md-wave-background: url("data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 1123 258'><path d='M1124,2c0,0 0,256 0,256l-1125,0l0,-48c0,0 16,5 55,5c116,0 197,-92 325,-92c121,0 114,46 254,46c140,0 214,-167 572,-166Z' style='fill: rgb(33 63 164)' /></svg>") no-repeat bottom,
  linear-gradient(
    to bottom,
    var(--md-primary-fg-color),
    #fff 96%,
    var(--md-primary-fg-color) 97%,
    var(--md-primary-fg-color)
  );
  --mdx-hero-color: var(--md-footer-bg-color);
}

.mdx-hero .md-button:not(.md-button--primary) {
  border-color: var(--mdx-hero-color);
  color: var(--mdx-hero-color);
}

.md-select__inner{
  color: var(--md-primary-bg-color);
}
