MOCK_MMICONFIG_PROD = {
    "portfolio": None,
    "custodians": [
        {
            "refreshTokenUrl": "https://hey.ho",
            "name": "qredo",
            "apiBaseUrl": "https://foo.bar",
        },
        {
            "refreshTokenUrl": "https://some.url",
            "name": "somename",
            "apiBaseUrl": "https://another.one",
        },
    ]
}
