MOCK_CACTUS_TRANSACTION_DETAIL_0 = {
    "transactionStatus": "completed",
    "transactionHash": "0x27a8aa70a501c20c7614aac084add4482482b51447804ff23275b1fb21e63927",
    "custodian_transactionId": "VURKJPZ2JVD888888000277",
    "gasPrice": "1000000007",
    "maxFeePerGas": "1400000012",
    "maxPriorityFeePerGas": "1000000008",
    "gasLimit": "180549",
    "nonce": "0",
    "from": "0xA7f5D02E141c5DF8A987833E01E4f0922A91cF29",
    "signature": None,
}
