body {
  background-color: white !important;
}

.md-header {
  background-color: white !important;
  color: black !important;
}

.md-header__option {
  display: none;
}

.md-source-date {
  font-style: italic;
}

.md-tabs {
  background-color: white !important;
  color: black !important;
}

.md-search__input {
  background-color: lightgray; !important;
  color: black !important;
}

.md-search-result {
  background-color: white !important;
  color: black !important;
}

.md-nav--secondary .md-nav__item .md-nav__item a.md-nav__link {
  font-weight: normal;
  font-size: inherit;
}

.md-nav--secondary a.md-nav__link {
  font-weight: normal;
  font-size: inherit;
}

.md-grid {
  background-color: white !important;
  color: black !important;
}

.mdx-container {
  background-color: white !important;
  background-image: none !important;
}

.md-main {
  background-color: white !important;
  border: none;
  color: black !important;
}

.mdx-hero {
  padding-top: 50px;
}

.mdx-hero__image {
  padding-top: 120px;
}

.mdx-hero__content h1 {
  display:  none;
}

.mdx-hero__content p {
  display:  none;
}

.md-button--primary {
  border: .1rem solid;
  border-color:  darkgray !important;
  color:  black !important;
  /*background-color: var(--hero-color) !important;*/
    /*border-radius: .1rem;*/
    /*cursor: pointer !important;*/
    font-weight: 700;
    padding: .625em 2em;
    transition: color 125ms,background-color 125ms,border-color 125ms;
}

.md-button {
  border: .1rem solid;
  border-color:  darkgray !important;
  color:  black !important;
  text-align: center;
  width: 100%;
}

.md-button:hover {
  color: white !important;
  background-color:  lightgray !important;
}

.md-content a[href^="http"]:not(.md-content__icon):after {
  font-family: "Material Icons";
  font-weight: 900;
  font-size: small;
  content: " \e89e";
}

.md-footer {
  margin-top: 2em;
  background-color: white; 
  border-color: white;
  color: black !important;
}

.md-footer-meta {
  background-color: white; 
  border-color: white;
  color: black !important;
}

.md-footer-meta__inner {
  background-color: white; 
  border-color: white;
  color: black !important;
}

.md-footer-copyright {
  color: black !important;
}

.md-footer-copyright a {
  color: black !important;
}

.md-footer-copyright__highlight {
  color: black !important;
}

.md-footer-social a {
  color: black !important;
}

/* ADMONITIONS some still TODO:  */
:root {
  --md-admonition-icon--critical: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 14h-2V9h2m0 9h-2v-2h2M1 21h22L12 2 1 21z'/></svg>")
}

.md-typeset .admonition.critical,
.md-typeset details.critical {
  border-color: rgb(222, 0, 0);
  background-color: #ffaaaa;
}

.md-typeset .admonition.critical strong{
  font-size: large;
}

.md-typeset .critical > .admonition-title,
.md-typeset .critical > summary {
  color: white;
  background-color: rgb(222, 0, 0);
  border-color: rgb(222, 0, 0);
}
.md-typeset .critical > .admonition-title::before,
.md-typeset .critical > summary::before {
  background-color: white;
  -webkit-mask-image: var(--md-admonition-icon--critical);
  mask-image: var(--md-admonition-icon--critical);
}

/*
[data-md-color-scheme="consensys"] {
  --md-primary-fg-color: #2C56DD;
  --md-primary-fg-color--light: #ABBBF1;
  --md-primary-fg-color--dark:  #000;
  --md-default-bg-color: #fff;
  --md-footer-bg-color: #213fa4;
}

.md-selected_language_item{
  border: solid;
  border-width: thin;
  border-radius: 0.1em;
}*/
