MOCK_QREDO_TRANSACTION_INFO = {
    "txID": "2ELuLA4HWIzPBQB1MSLmbOxtoB1",
    "txHash": "0x6b5dc3519b325be4e6f9512f8d3b1fdb7af22a996e3f6bb1a898a28ef05c1963",
    "status": "authorized",
    "timestamps": {
        "authorized": 1662387127,
        "created": 1662387126
    },
    "events": [{
        "id": "2ELuLAcfbNcFqCmYPHlaGlkIdQf",
        "timestamp": 1662387126,
        "status": "created",
        "message": ""
    },
        {
        "id": "2ELuLBuOP6tc1Pp09FSHKvfvOoZ",
        "timestamp": 1662387127,
        "status": "authorized",
        "message": ""
    }],
    "nonce": 0,
    "gasPrice": "1000",
    "gasLimit": "21000",
    "from": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
    "to":   "0x9999999999999999999999999999999999999999",
    "value": "1",
    "data": "",
    "rawTX": "4YCCA-iCUgiUYkaP2Ra_J6O3bT3i5SgOUweOE-EBgICAgA",
    "createdBy": "EFvSMt9uGTEsDCx22sYB8BPz1bCyxAZNPKDWpJVsLKM9",
    "accountID": "2ECrNK9dUlYIpdI4xVuRQ4Diuwq",
    "network": "",
    "chainID": "1"
}
